This module contains the Shell trait and implementations for various
shells.
Structs
- Bash
- A
Shellimplementation for the Bash shell. - CmdExe
- A
Shellimplementation for the cmd.exe shell. - Fish
- A
Shellimplementation for the Fish shell. - NuShell
- A
Shellimplementation for the Bash shell. - Parse
Shell Enum Error - Parsing of a shell was not possible. The shell most likely is not supported.
- Power
Shell - A
Shellimplementation forPowerShell. - Shell
Script - A helper struct for generating shell scripts.
- Xonsh
- A
Shellimplementation for the Xonsh shell. - Zsh
- A
Shellimplementation for the Zsh shell.
Enums
- Shell
Enum - A generic
Shellimplementation for concrete shell types. - Shell
Error - An error that can occur when working with shell scripts.
Traits
- Shell
- A trait for generating shell scripts. The trait is implemented for each shell individually.