pub enum ShellEnum {
Bash(Bash),
Zsh(Zsh),
Xonsh(Xonsh),
CmdExe(CmdExe),
PowerShell(PowerShell),
Fish(Fish),
NuShell(NuShell),
}Expand description
A generic Shell implementation for concrete shell types.
Variants
Implementations
Sourceimpl ShellEnum
impl ShellEnum
Sourcepub fn from_shell_path<P: AsRef<Path>>(path: P) -> Option<Self>
pub fn from_shell_path<P: AsRef<Path>>(path: P) -> Option<Self>
Parse a shell from a path to the executable for the shell.
Sourcepub fn from_env() -> Option<Self>
pub fn from_env() -> Option<Self>
Determine the user’s current shell from the environment
This will read the SHELL environment variable and try to determine which shell is in use from that.
If SHELL is set, but contains a value that doesn’t correspond to one of
the supported shell types, then return None.